# config.pm
# get the configuration options
# also has the usage routine
package config;

use strict;

use vars qw($login $password $forward_to $smtp_server $service $proxy $proxy_auth $speed_limit $retry_limit $verbosity $check_only $error_address);

$login = "";			# users login name
$password = "";			# users password
$forward_to = "";		# address to forward the emails to
$smtp_server = "";		# smtp server to use
$service = "";			# indicate which service - hotmail, mail.com etc
$proxy = "";			# http proxy server
$proxy_auth = "";		# proxy authorisation
$speed_limit = 0;		# if set, sleeps for 1 second between page retrievals
$retry_limit = 2;		# number of times to retry failed page retrievals
$verbosity = 0;			# verboseness  -1=silent, 0=normal, 1=verbose, 2=debug
$check_only = 0;		# just check for new mail - don't retrieve or anything

$error_address = 'foo@bar.com'; # this address is used to send error messages from - change it!!


sub show_usage()
{
	# show the options usage and exit
	$config::verbosity = 0;
	utils::intro_text();

	print "Usage:\ngetwmail [OPTIONS]\n";

	print "\nOptions:\n";
	print "  -?, --help, --usage          Display this screen\n";
	print "  --version                    Display version information\n";
	print "  -u <username>                Specify your mail username (REQUIRED)\n";
	print "  -p <password>                Specify your mail password (REQUIRED)\n";
	print "  -w <h|m>                     Specify the webmail service h=hotmail, m=mail.com (REQUIRED)\n";
	print "  -f <emailaddress>            Specify an email address to forward to\n";
	print "  -s <smtp server>             Specify the SMTP server to use\n";
	print "  --check                      Only check for new mail\n";
	print "  --proxy <host:port>          Specify an HTTP proxy to use\n";
	print "  --proxyauth <user:password>  Specify authentification details for the HTTP proxy\n";
	print "  --retries <maxtries>         Maximum number of attempts to download a message\n";
	print "  --speed <0|1>                Throttle back rate of forwarding messages\n";
	print "  --silent                     Do not print messages\n";
	print "  --verbose                    Verbosely print messages\n";
	print "  --debug                      Print debug output\n";

	exit(-1);
}


# parse all the configuration settings
# first, read in a config file (if it exists) and then apply the settings from the 
# command line
sub parse_config {

	# Check for and open a config file
	if (open(RCFILE, $ENV{"HOME"} . "/.getwmailrc")) {
		# Parse the file
		while (<RCFILE>) {
			next if ($_ =~ /^#/);
			if ($_ =~ /^user=(.+)/i) {
				$login = $1;		# login name
			} elsif ($_ =~ /^password=(.+)/i) {
				$password = $1;		# password
			} elsif ($_ =~ /^service=(.+)/i) {
				$service = $1;		# webmail service
			} elsif ($_ =~ /^forward=(.+)/i) {
				$forward_to = $1;	# email address to forward to
			} elsif ($_ =~ /^smtp=(.+)/i) {
				$smtp_server = $1;	# smtp server
			} elsif ($_ =~ /^check/i) {
				$check_only = -1;	# check for new mail only
			} elsif ($_ =~ /^proxy=(.+)/i) {
				$proxy = $1;		# proxy
			} elsif ($_ =~ /^proxyauth=(.+)/i) {
				$proxy_auth = $1;	# proxy_auth
			} elsif ($_ =~ /^retries=([0-9]+)/i) {
				$retry_limit = $1;	# retry limit
			} elsif ($_ =~ /^speed=(.+)/i) {
				$speed_limit = 1;	# speed limit
			} elsif ($_ =~ /^silent/i) {
				$verbosity = -1;	# verbosity
			} elsif ($_ =~ /^verbose/i) {
				$verbosity = 1;		# verbosity
			} elsif ($_ =~ /^debug/i) {
				$verbosity = 2;		# verbosity
	                }
		}
		close(RCFILE);
	}

	# now go through the command line arguments
	while(@ARGV) { 
		my($element)=shift(@ARGV);
		if (($element =~ /-^\?/i) || ($element =~ /--help/i) || ($element =~ /--usage/i))
		{
			show_usage();
		}
		elsif ($element =~ /^--version/) {
			dispVersionText();
		}
		elsif ($element =~ /^-u/i) {
			if (@ARGV) {
				$login = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^-p/i) {
			if (@ARGV) {
				$password = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /-w/i) {
			if (@ARGV) {
				$service = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^-f/i) {
			if (@ARGV) {
				$forward_to = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /-s/i) {
			if (@ARGV) {
				$smtp_server = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^--check/i) {
			$check_only = 1;
		}
		elsif ($element =~ /^--proxy/i)
		{
			if(@ARGV) {
				$proxy = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^--proxyauth/i)
		{
			if(@ARGV) {
				$proxy_auth = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^--retries/i) {
			if (@ARGV) {
				$retry_limit = shift(@ARGV);
			} else {
				show_usage();
			}
		}
		elsif ($element =~ /^--speed/i) {
			$speed_limit = 1;
		}
		elsif ($element =~ /^--silent/i) {
			$verbosity = -1;
		}
		elsif ($element =~ /^--verbose/i) {
			$verbosity = 1;
		}
		elsif ($element =~ /^--debug/i) {
			$verbosity = 2;
		}
		else {
			utils::show_text("Unrecognised option $element\n",0);
			show_usage();
		}
	}

	# if we are checking, we only need login, password and service
	if ($check_only == 1) {
		if (($login eq "") || ($password eq "") || (($service ne "h") && ($service ne "m")) ) {
			utils::show_text("A username, password and valid service are REQUIRED.\n",0);
			show_usage();
		}
	} else {
		if (($login eq "") || ($password eq "") || ($forward_to eq "") || ($smtp_server eq "") ||
		(($service ne "h") && ($service ne "m")) ) {
			utils::show_text("A username, password, forwarding address, smtp server and valid service are REQUIRED.\n",0);
			show_usage();
		}
	}
}

1;
